@@ -2,9 +2,9 @@ use strict;
 use warnings;
 
 package Net::Trac;
-use Moose;
+use Any::Moose;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use Net::Trac::Connection;
 use Net::Trac::Ticket;
